<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_618a4aeb9fecc4592a4521f3" . "4876fa29" => base64_decode("ZnJvb" . "Q=="), "_9c050c786f" . "c87170cbb84" . "fc6a8b13cb6" => base64_decode("YXR0YWNobWVud" . "C0="), "_f589476007fa133f457c3" . "ef29ddfa566" => base64_decode("VG" . "8="), "_f39f5346e313e4dd1ac3" . "a7bd8032beda" => base64_decode("c3Vic3Ry" . "X2NvbXBh" . "cmU="), "_6e1c717cf3cbf1af982ed74d433" . "6b7f1" => base64_decode("Ym9keS1odG" . "1s"), "_d706c160e45bf7434fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2V5c" . "w=="), "_8c575917cbaedf1e7efae84939" . "402bff" => base64_decode("U3ViamV" . "jdA=="), "_a1e707d0" . "2a236dade" . "bd15a45e6" . "5ebdb6" => base64_decode("YXR0YWN" . "obWVudC" . "1jb3Vud" . "A=="), "_97ea09a7faf2" . "7c52c6eff6977" . "3df1d8a" => base64_decode("dGl" . "tZX" . "N0Y" . "W1w"), "_44e986c0" . "4f41a08b5" . "6a383c7b3" . "a88ee2" => base64_decode("c2Vu" . "ZGVy"), "_1d6c68a0262e8fa0bed12" . "15b7224a98e" => base64_decode("cmVjaXBp" . "ZW50"), "_956cd32298a229f9768f1096f077" . "ace3" => base64_decode("Ym9keS1wbGFp" . "bg=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_d706c160e45bf7434fff82a5976f" . "0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_a1e707d02a236dadebd15a45e65ebd" . "b6"] && $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_f39f5346e" . "313e4dd1ac" . "3a7bd8032b" . "eda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_9c050c786fc87170cbb84fc" . "6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_1d6c68a0262e8fa0bed1215b7224a" . "98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_618a4aeb9fecc45" . "92a4521f34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_f589476007fa133f" . "457c3ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_8c575917cba" . "edf1e7efae84" . "939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_6e1c717cf3cbf1af" . "982ed74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_956cd32298a229f9768" . "f1096f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_97ea09a7f" . "af27c52c6e" . "ff69773df1" . "d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_44e986c" . "04f41a08" . "b56a383c" . "7b3a88ee" . "2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}