<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_67a0d624ae" . "bcceb0abd5c" . "e56a53ff06f" => base64_decode("ZGF0ZQ=" . "="), "_460e1aeb3113a1676ce59a" . "8f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJl" . "IHByb2plY3Q="), "_376d30c40857357a4d4cbb1" . "ffaa25817" => base64_decode("dG8" . "="), "_03b1f0cee835" . "582d1158dce26" . "78b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCB" . "yZWNlaXZlZCBzdWJzY3JpYmVy"), "_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128" => base64_decode("Ym9" . "keV" . "90Z" . "Xh0"), "_bfda889b74ea561b14325" . "e30e7d75426" => base64_decode("Ym9" . "keV" . "9od" . "G1s"), "_618a4aeb9fecc" . "4592a4521f3487" . "6fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_f656816961e8573806141" . "c558b184fe2" => base64_decode("c3Viam" . "VjdA=="), "_e608e5b5c4c34a67ba97ef84" . "c1e16199" => base64_decode("Jw" . "=="), "_a3d82c5df38e194c9c73e3ccb4223" . "bbc" => base64_decode("ZW1haW" . "xfZGF0" . "YQ=="), "_5d40a2cf1c525fb252b" . "f5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlb" . "nRpZmllZCBmb3IgbWFpbDsgc3ViamVjdCAn"), "_c35473364fa7a050299058f33" . "2ec29c1" => base64_decode("ZXhjZ" . "XB0aW" . "9u"), "proj" . "ect_" . "id" => base64_decode("cHJvamVjd" . "F9pZA=="), "_9b16fa2683095e67d7c8b265a8081d" . "0b" => base64_decode("TWFpbFJlY" . "2VpdmVkRX" . "ZlbnRSZWN" . "laXZlcg=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_9b16fa268" . "3095e67d7c" . "8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_03b1f0cee835582d1158dce2678b5" . "05c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_5d40a2cf1c525fb252bf55" . "99e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_e608e5b5c4c34a67ba97ef84" . "c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_618a4aeb9fecc4592a4521f3487" . "6fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_376d30c40857357a4d4c" . "bb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_f656816961e85738" . "06141c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_ced92d7" . "b391285c" . "8a26846f" . "1f4bd312" . "8"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_bfda889b74ea561b14325e30e7d754" . "26"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_67a0d624aebcceb" . "0abd5ce56a53ff06" . "f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_460e1aeb3113a1676ce5" . "9a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["project_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_a3d82c5df38e194c9" . "c73e3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_c35473364f" . "a7a05029905" . "8f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}